<?php
/* =========================================================================
                                                    ++++++++++++++++++++++++
                                                    ++  rp_recentlinks()  ++
                                                    ++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the most recent links added to your linklog.

$limit
    The number of links to display.
    Defaults to 12.

$use_permalink
    Use permalinks for your links? True or False.
    Defaults to false.

$permalink_beginning
    Permalink at the beginning of the link? True or Flase.
    Defaults to True.

$permalink_icon
    Permalink icon used.
    Defaults to the commonly-used '#' character.

$inline_caption
    Use inline captions, in addition to the title attribute.
    Defaults to false.

$date_append
    Date format of the date string added for a link's title attribute.
    This is based on PHP's date() function.
    Defaults to 'F j', which displays March 22.
    Other suggested formats:
        jS M Y @ g A    ==>     22nd Mar 2004 @ 5 PM
        M j             ==>     Mar 22

$before
    String to add before the link-formatted text.
    Defaults to "<li>"

$after
    String to add after the link-formatted text.
    Defaults to "</li>"

$between
    String to add after a link. This is added after the $after string.
    Defaults to "\n" (newline)

========================================================================= */
// 2004-05-18 16:57:11
function rp_recentlinks($limit = 12,
                        $use_permalink = false,
                        $permalink_beginning = true,
                        $permalink_icon = '#',
                        $inline_caption = false,
                        $date_append = 'F j',
                        $before = '<li>',
                        $after = '</li>',
                        $between = "\n")
{
    global $table_prefix, $wpdb;

    $tablerecentlinks = $table_prefix.'recentlinks';
    $a_tag = '[a]';
    $a_tag2 = '[/a]';
    $time_difference = get_settings('time_difference');

    if ('' != $limit) {
        $limit = (int) $limit;
        $limit = " LIMIT $limit";
    }

    $now = date('Y-m-d H:i:s',(time() + ($time_difference * 3600)));
    $sql = "SELECT ID, link_url, link_text, link_caption, link_rel, link_target, link_visible, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND link_visible = 'Y' ORDER BY date_added DESC $limit";

    $links = $wpdb->get_results($sql);

    if ($links) {

        $out = '';
        foreach ($links as $link) {

            $link->link_text = stripslashes($link->link_text);
            $link->link_url = stripslashes($link->link_url);
            $link->link_caption = stripslashes($link->link_caption);
            $link->link_rel = stripslashes($link->link_rel);
            $link->link_target = stripslashes($link->link_target);

            $this_date = date($date_append, strtotime($link->date_added));

            if (strlen($link->link_caption) > 0) {
                $piped_caption = ' | '.$link->link_caption;
            } else {
                $piped_caption = '';
            }

            if (strlen($link->link_rel) == 0) {
                $rel = '';
            } else {
                $rel = ' rel="'.$link->link_rel.'"';
            }

            if (strlen($link->link_target) == 0) {
                $target = '';
            } else {
                $target = ' target="'.$link->link_target.'"';
            }


            if (  is_int(strpos($link->link_url, '&'))  &&  !strpos($link->link_url, '&amp;')  &&  !strpos($link->link_url, '&#038;')  ) {
                $link->link_url = str_replace('&', '&amp;', $link->link_url);
            }


            if (  is_int(strpos($link->link_text, $a_tag))  &&  is_int(strpos($link->link_text, $a_tag2))  ) {
                $pos_open = strpos($link->link_text, $a_tag);
                $pos_close = strpos($link->link_text, $a_tag2, $pos_open);

                $prefix = substr($link->link_text, 0, $pos_open);
                $suffix = substr($link->link_text, $pos_close + strlen($a_tag2));

                $middle = substr($link->link_text, $pos_open + strlen($a_tag), $pos_close - ($pos_open + strlen($a_tag)));

                $new_link = $prefix.'<a href="'.$link->link_url.'" title="'.wptexturize($this_date.$piped_caption).'"'.$rel.$target.'>'.wptexturize($middle).'</a>'.$suffix;
            } else {
                $new_link = '<a href="'.$link->link_url.'" title="'.wptexturize($this_date.$piped_caption).'"'.$rel.$target.'>'.wptexturize($link->link_text).'</a>';
            }


            if ($use_permalink) {
                $siteurl = get_settings('siteurl');
                $rewrite = get_settings('permalink_structure');
                if (strlen($permalink_icon) == 0) {
                    $permalink_icon = '#';
                }
                if (strlen($rewrite) > 0) { // using mod_rewrite
                    $permalink_url = $siteurl.'/recent-links/'.date('Y/m', strtotime($link->date_added)).'/#rlink-'.$link->ID;
                } else {
                    $permalink_url = $siteurl.'/wp-recent-links.php?y='.date('Y', strtotime($link->date_added)).'&amp;m='.date('m', strtotime($link->date_added)).'#rlink-'.$link->ID;
                }

                if ($permalink_beginning) {
                    $new_link = '<a href="'.$permalink_url.'" title="Permalink to this resource on this site.">'.$permalink_icon.'</a> '.$new_link;
                } else {
                    $new_link = $new_link.' <a href="'.$permalink_url.'"title="Permalink to this resource on this site.">'.$permalink_icon.'</a>';
                }
            }


            if ($inline_caption) {
                $new_link = $new_link.'<br />'.wptexturize($link->link_caption);
            }


            $out .= $before.$new_link.$after.$between;

        }
    }
    echo $out;
}
// alias for old function, for backward compatibility
function rpmod_recentlinks($limit = 12, $before = '<li>', $after = '</li>', $between = "\n", $date_append = 'F j')
{
    return rp_recentlinks($limit, false, false, '', false, $date_append, $before, $after, $between);
}












/* =========================================================================
                                       +++++++++++++++++++++++++++++++++++++
                                       ++  rp_recentlinks_archives_url()  ++
                                       +++++++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the URL of the archives page for the
recent links plugin.

========================================================================= */
function rp_recentlinks_archives_url()
{
    $siteurl = get_settings('siteurl');
    $rewrite = get_settings('permalink_structure');

    if (strlen($rewrite) > 0) { // using mod_rewrite
        echo $siteurl.'/recent-links/';
    } else {
        echo $siteurl.'/wp-recent-links.php';
    }
}
// alias for old function, for backward compatibility
function rpmod_recentlinks_archives_url()
{
    return rp_recentlinks_archives_url();
}















/* =========================================================================
                                           +++++++++++++++++++++++++++++++++
                                           ++  rp_recentlinks_rss2_url()  ++
                                           +++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the URL of the RSS 2 feed for the
recent links plugin.

========================================================================= */
// 2004-05-18 17:07:04
function rp_recentlinks_rss2_url()
{
    $siteurl = get_settings('siteurl');
    $rewrite = get_settings('permalink_structure');

    if (strlen($rewrite) > 0) { // using mod_rewrite
        echo $siteurl.'/recent-links/feed/';
    } else {
        echo $siteurl.'/wp-recent-links-rss2.php';
    }
}
// alias for old function, for backward compatibility
function rpmod_recentlinks_rss2_url()
{
    return rp_recentlinks_rss2_url();
}









/* =========================================================================
                                              ++++++++++++++++++++++++++++++
                                              ++  rp_recentlinks_month()  ++
                                              ++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the links for the given month.

$limit
    The number of links to display.
    Defaults to 12.

$show_link_count
    Show link count for given month? True or False.
    Defaults to false.

$use_permalink
    Use permalinks for your links? True or False.
    Defaults to false.

$permalink_beginning
    Permalink at the beginning of the link? True or Flase.
    Defaults to True.

$permalink_icon
    Permalink icon used.
    Defaults to the commonly-used '#' character.

$inline_caption
    Use inline captions, in addition to the title attribute.
    Defaults to false.

$date_append
    Date format of the date string added for a link's title attribute.
    This is based on PHP's date() function.
    Defaults to 'F j', which displays March 22.
    Other suggested formats:
        jS M Y @ g A    ==>     22nd Mar 2004 @ 5 PM
        M j             ==>     Mar 22
$before
    String to add before the link-formatted text.
    Defaults to "<li>"

$after
    String to add after the link-formatted text.
    Defaults to "</li>"

$between
    String to add after a link. This is added after the $after string.
    Defaults to "\n" (newline)

========================================================================= */
// 2004-05-18 17:06:57
function rp_recentlinks_month($limit = '',
                                $show_link_count = false,
                                $use_permalink = false,
                                $permalink_beginning = true,
                                $permalink_icon = '#',
                                $inline_caption = false,
                                $date_append = 'F j',
                                $before = '<li>',
                                $after = '</li>',
                                $between = "\n")
{
    global $table_prefix, $wpdb;
    $tablerecentlinks = $table_prefix.'recentlinks';
    $a_tag = '[a]';
    $a_tag2 = '[/a]';
    $time_difference = get_settings('time_difference');

    $y = strip_tags($_REQUEST['y']);
    $m = strip_tags($_REQUEST['m']);

    if ('' != $limit) {
        $limit = (int) $limit;
        $limit = " LIMIT $limit";
    }


    $now = date('Y-m-d H:i:s',(time() + ($time_difference * 3600)));

    $links = $wpdb->get_results("SELECT ID, link_url, link_text, link_caption, link_rel, link_target, link_visible, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND link_visible = 'Y' AND YEAR(date_added) = '$y' AND MONTH(date_added) = '$m' ORDER BY date_added DESC" . $limit);

    if ($links) {

        $out = '';
        foreach ($links as $link) {

            $link->link_text = stripslashes($link->link_text);
            $link->link_url = stripslashes($link->link_url);
            $link->link_caption = stripslashes($link->link_caption);
            $link->link_rel = stripslashes($link->link_rel);
            $link->link_target = stripslashes($link->link_target);

            $this_date = date($date_append, strtotime($link->date_added));

            if (strlen($link->link_caption) > 0) {
                $piped_caption = ' | '.$link->link_caption;
            } else {
                $piped_caption = '';
            }

            if (strlen($link->link_rel) == 0) {
                $rel = '';
            } else {
                $rel = ' rel="'.$link->link_rel.'"';
            }
            if (strlen($link->link_target) == 0) {
                $target = '';
            } else {
                $target = ' target="'.$link->link_target.'"';
            }

            // ID for permalinks
            $id = ' id="rlink-'.$link->ID.'"';


            if (  is_int(strpos($link->link_url, '&'))  &&  !strpos($link->link_url, '&amp;')  &&  !strpos($link->link_url, '&#038;')  ) {
                $link->link_url = str_replace('&', '&amp;', $link->link_url);
            }


            if (  is_int(strpos($link->link_text, $a_tag))  &&  is_int(strpos($link->link_text, $a_tag2))  ) {
                $pos_open = strpos($link->link_text, $a_tag);
                $pos_close = strpos($link->link_text, $a_tag2, $pos_open);

                $prefix = substr($link->link_text, 0, $pos_open);
                $suffix = substr($link->link_text, $pos_close + strlen($a_tag2));

                $middle = substr($link->link_text, $pos_open + strlen($a_tag), $pos_close - ($pos_open + strlen($a_tag)));

                $new_link = $prefix.'<a href="'.$link->link_url.'" title="'.wptexturize($this_date.$piped_caption).'"'.$rel.$target.$id.'>'.wptexturize($middle).'</a>'.$suffix;
            } else {
                $new_link = '<a href="'.$link->link_url.'" title="'.wptexturize($this_date.$piped_caption).'"'.$rel.$target.$id.'>'.wptexturize($link->link_text).'</a>';
            }


            if ($use_permalink) {
                $siteurl = get_settings('siteurl');
                $rewrite = get_settings('permalink_structure');
                if (strlen($permalink_icon) == 0) {
                    $permalink_icon = '#';
                }
                if (strlen($rewrite) > 0) { // using mod_rewrite
                    $permalink_url = $siteurl.'/recent-links/'.date('Y/m', strtotime($link->date_added)).'/#rlink-'.$link->ID;
                } else {
                    $permalink_url = $siteurl.'/wp-recent-links.php?y='.date('Y', strtotime($link->date_added)).'&amp;m='.date('m', strtotime($link->date_added)).'#rlink-'.$link->ID;
                }


                if ($permalink_beginning) {
                    $new_link = '<a href="'.$permalink_url.'" title="Permalink to this resource on this site.">'.$permalink_icon.'</a> '.$new_link;
                } else {
                    $new_link = $new_link.' <a href="'.$permalink_url.'" title="Permalink to this resource on this site.">'.$permalink_icon.'</a>';
                }
            }

            if ($inline_caption) {
                $new_link = $new_link.'<br />'.wptexturize($link->link_caption);
            }


            $out .= $before.$new_link.$after.$between;

        }
    }
    echo $out;
}
// alias for old function, for backward compatibility
function rpmod_recentlinks_month($limit = '', $before = '<li>', $after = '</li>', $between = "\n", $show_link_count = false)
{
    return rp_recentlinks_month($limit, false, false, true, '#', false, 'F j', $before, $after, $between);
}















/* =========================================================================
                                           +++++++++++++++++++++++++++++++++
                                           ++  rp_recentlinks_archives()  ++
                                           +++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the monthly archives for the recent links plugin.

$limit
    The number of links to display.
    Defaults to '', which shows all.

$show_link_count
    Show link count for given month? True or False.
    Defaults to false.

$before
    String to add before the link-formatted text.
    Defaults to "<li>"

$after
    String to add after the link-formatted text.
    Defaults to "</li>"

$between
    String to add after a link. This is added after the $after string.
    Defaults to "\n" (newline)

========================================================================= */
function rp_recentlinks_archives($limit = '',
                                    $show_link_count = false,
                                    $before = '<li>',
                                    $after = '</li>',
                                    $between = "\n")
{
    global $table_prefix, $wpdb;
    $siteurl = get_settings('siteurl');
    $tablerecentlinks = $table_prefix.'recentlinks';
    $time_difference = get_settings('time_difference');

    $rewrite = get_settings('permalink_structure');

    if ('' != $limit) {
        $limit = (int) $limit;
        $limit = " LIMIT $limit";
    }


    $now = date('Y-m-d H:i:s',(time() + ($time_difference * 3600)));

    $arcresults = $wpdb->get_results("SELECT DISTINCT YEAR(date_added) AS `year`, MONTH(date_added) AS `month`, count(ID) as links, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND link_visible = 'Y' GROUP BY YEAR(date_added), MONTH(date_added) ORDER BY date_added DESC" . $limit);

    if ($arcresults) {
        $out = '';
        foreach ($arcresults as $month) {
            if (strlen($rewrite) > 0) {
                $url = $siteurl.'/recent-links/'.date('Y/m/', strtotime($month->date_added));
            } else {
                $url = $siteurl.'/wp-recent-links.php?y='.date('Y', strtotime($month->date_added)).'&amp;m='.date('m', strtotime($month->date_added));
            }

            if ($show_link_count) {
                $link_count = ' ('.$month->links.')';
            } else {
                $link_count = '';
            }

            $link = '<a href="'.$url.'" title="'.date('F Y', strtotime($month->date_added)).'">'.date('F Y', strtotime($month->date_added)).'</a>'. $link_count;

            $out .= $before.$link.$after.$between;
        }

    }
    echo $out;
}
// alias for old function, for backward compatibility
function rpmod_recentlinks_archives($limit = '', $before = '<li>', $after = '</li>', $between = "\n", $show_link_count = false)
{
    return rp_recentlinks_archives($limit, $show_link_count, $before, $after, $between);
}



?>